@@ -53,22 +53,29 @@ my %filters = (
 );
 
 my @inputs = split /,/, $input_names;
+my $name = $inputs[0];
 
 # open the inputs
 my %controllers;
 my $control = MIDI::RtController->new(
-    input   => $inputs[0],
+    input   => $name,
     output  => $output_name,
     verbose => 1,
 );
-$controllers{ $inputs[0] } = $control;
-for my $name (@inputs[1 .. $#inputs]) {
-    $controllers{$name} = MIDI::RtController->new(
-        input    => $name,
+$controllers{$name}->{rtc}    = $control;
+$controllers{$name}->{filter} = MIDI::RtController::Filter::CC->new(
+    rtc => $control
+);
+for my $i (@inputs[1 .. $#inputs]) {
+    $controllers{$i}->{rtc} = MIDI::RtController->new(
+        input    => $i,
         loop     => $control->loop,
         midi_out => $control->midi_out,
         verbose  => 1,
     );
+    $controllers{$i}->{filter} = MIDI::RtController::Filter::CC->new(
+        rtc => $controllers{$i}->{rtc}
+    );
 }
 
 # add the filters
@@ -77,13 +84,13 @@ for my $cc (keys %filters) {
     my $port   = delete $params{port}  || $control->input;
     my $type   = delete $params{type}  || 'single';
     my $event  = delete $params{event} || 'all';
-    my $filter = MIDI::RtController::Filter::CC->new(rtc => $controllers{$port});
+    my $filter = $controllers{$port}->{filter};
     $filter->control($cc);
     for my $param (keys %params) {
         $filter->$param($params{$param});
     }
     my $method = "curry::$type";
-    $controllers{$port}->add_filter($type, $event => $filter->$method);
+    $controllers{$port}->{rtc}->add_filter($type, $event => $filter->$method);
 }
 
 $control->run;
@@ -92,7 +99,8 @@ $control->run;
 
 # XXX maybe needed?
 END: {
-    for my $name (@inputs) {
-        Object::Destroyer->new($controllers{$name}, 'delete');
+    for my $i (@inputs) {
+        Object::Destroyer->new($controllers{$i}->{rtc}, 'delete');
+        Object::Destroyer->new($controllers{$i}->{filter}, 'delete');
     }
 }
