@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0605';
+our $VERSION = '0.0700';
 
 use v5.36;
 
@@ -14,7 +14,7 @@ use Iterator::Breathe ();
 use Moo;
 use Types::MIDI qw(Channel Velocity);
 use Types::Common::Numeric qw(PositiveNum);
-use Types::Standard qw(Bool Num);
+use Types::Standard qw(Bool Num Maybe);
 use namespace::clean;
 
 
@@ -41,8 +41,15 @@ has control => (
 
 has value => (
     is      => 'rw',
-    isa     => Num,
-    default => 1,
+    isa     => Maybe[Num],
+    default => undef,
+);
+
+
+has trigger => (
+    is      => 'rw',
+    isa     => Maybe[Num],
+    default => undef,
 );
 
 
@@ -103,6 +110,10 @@ has running => (
 
 
 sub single ($self, $device, $dt, $event) {
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if $self->trigger && $note != $self->trigger;
+    return 0 if $self->value && $val != $self->value;
+
     my $cc = [ 'control_change', $self->channel, $self->control, $self->value ];
     $self->rtc->send_it($cc);
     return 0;
@@ -111,6 +122,11 @@ sub single ($self, $device, $dt, $event) {
 
 sub breathe ($self, $device, $dt, $event) {
     return 0 if $self->running;
+
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if $self->trigger && $note != $self->trigger;
+    return 0 if $self->value && $val != $self->value;
+
     $self->running(1);
 
     my $it = Iterator::Breathe->new(
@@ -136,6 +152,11 @@ sub breathe ($self, $device, $dt, $event) {
 
 sub scatter ($self, $device, $dt, $event) {
     return 0 if $self->running;
+
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if $self->trigger && $note != $self->trigger;
+    return 0 if $self->value && $val != $self->value;
+
     $self->running(1);
 
     my $value  = $self->initial_point;
@@ -158,6 +179,11 @@ sub scatter ($self, $device, $dt, $event) {
 
 sub stair_step ($self, $device, $dt, $event) {
     return 0 if $self->running;
+
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if $self->trigger && $note != $self->trigger;
+    return 0 if $self->value && $val != $self->value;
+
     $self->running(1);
 
     my $it = Iterator::Breathe->new(
@@ -200,6 +226,11 @@ sub stair_step ($self, $device, $dt, $event) {
 
 sub ramp ($self, $device, $dt, $event) {
     return 0 if $self->running;
+
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if $self->trigger && $note != $self->trigger;
+    return 0 if $self->value && $val != $self->value;
+
     $self->running(1);
 
     my $value = $self->initial_point;
@@ -243,7 +274,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0605
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -326,10 +357,21 @@ Default: C<1> (mod-wheel)
   $filter->value($number);
 
 Return or set the control change value. This is a generic setting that
-can be used by filters to set state. This often a whole number between
-C<0> and C<127>, but can take any number.
+can be used by filters to set or retrieve state. This often a whole
+number between C<0> and C<127>, but can take any number.
 
-Default: C<0>
+Default: C<undef>
+
+=head2 trigger
+
+  $trigger = $filter->trigger;
+  $filter->trigger($number);
+
+Return or set the trigger. This is a generic setting that
+can be used by filters to set or retrieve state. This often a whole
+number between C<0> and C<127>, but can take any number.
+
+Default: C<undef>
 
 =head2 initial_point
 
@@ -420,6 +462,10 @@ Return a new C<MIDI::RtController::Filter::CC> object.
 This filter sets a single B<control> change message, over the MIDI
 B<channel> once.
 
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
 =head2 breathe
 
   $control->add_filter('breathe', all => $filter->curry::breathe);
@@ -431,6 +477,10 @@ a B<control> change message, over the MIDI B<channel> every iteration.
 Passing C<all> means that any MIDI event will cause this filter to be
 triggered.
 
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
 =head2 scatter
 
   $control->add_filter('scatter', all => $filter->curry::scatter);
@@ -442,6 +492,10 @@ B<control> change message, over the MIDI B<channel>, every iteration.
 The B<initial_point> is used as the first CC# message, then the
 randomization takes over.
 
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
 =head2 stair_step
 
   $control->add_filter('stair_step', all => $filter->curry::stair_step);
@@ -451,6 +505,10 @@ the fist CC# message, then adds B<step_up> or subtracts B<step_down>
 from that number successively, sending the value as a B<control>
 change message, over the MIDI B<channel>, every iteration.
 
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
 =head2 ramp
 
   $control->add_filter('ramp', all => $filter->curry::ramp);
@@ -459,6 +517,10 @@ This filter ramps-up (or down) a B<control> change message, over the
 MIDI B<channel>, from B<range_bottom> until the B<range_top> is
 reached.
 
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
 =head1 SEE ALSO
 
 The F<eg/*.pl> program(s) in this distribution
